// טעינת ההגדרות בטעינת הדף
document.addEventListener('DOMContentLoaded', () => {
    loadSettings();
});

// טעינת ההגדרות מהזיכרון
function loadSettings() {
    chrome.storage.sync.get({
        playerMode: 'floating',
        windowWidth: 400,
        windowHeight: 300,
        windowPosition: 'bottom-right',
        showPreview: true
    }, (settings) => {
        // הגדרת מצב הנגן
        document.querySelector(`input[name="playerMode"][value="${settings.playerMode}"]`).checked = true;

        // הגדרת גודל החלון
        document.getElementById('windowWidth').value = settings.windowWidth;
        document.getElementById('windowHeight').value = settings.windowHeight;

        // הגדרת מיקום החלון
        document.querySelectorAll('.position-button').forEach(button => {
            button.classList.toggle('selected', button.dataset.position === settings.windowPosition);
        });

        // הגדרת תצוגה מקדימה
        document.getElementById('showPreview').checked = settings.showPreview;

        // הצגת/הסתרת אפשרויות החלון הצף בהתאם למצב
        toggleFloatingOptions(settings.playerMode === 'floating');
    });
}

// פונקציה להצגת הודעת הצלחה
function showSuccessMessage(button, originalText, successText) {
    button.classList.add('save-success');
    button.textContent = successText;
    
    setTimeout(() => {
        button.classList.remove('save-success');
        button.textContent = originalText;
    }, 1500);
}

// שמירת הגדרות
function saveSettings() {
    const isFloating = document.querySelector('input[name="playerMode"]:checked').value === 'floating';
    const settings = {
        playerMode: document.querySelector('input[name="playerMode"]:checked').value,
        windowWidth: isFloating ? (parseInt(document.getElementById('windowWidth').value) || 400) : 400,
        windowHeight: isFloating ? (parseInt(document.getElementById('windowHeight').value) || 300) : 300,
        windowPosition: isFloating ? (document.querySelector('.position-button.selected')?.dataset.position || 'bottom-right') : 'bottom-right',
        showPreview: document.getElementById('showPreview').checked
    };

    chrome.storage.sync.set(settings, () => {
        showSuccessMessage(
            document.getElementById('saveSettings'),
            'שמור הגדרות',
            'נשמר בהצלחה!'
        );
    });
}

// איפוס הגדרות
function resetSettings() {
    const defaultSettings = {
        playerMode: 'floating',
        windowWidth: 400,
        windowHeight: 300,
        windowPosition: 'bottom-right',
        showPreview: true
    };
    
    chrome.storage.sync.set(defaultSettings, () => {
        // עדכון הממשק
        document.querySelector('input[name="playerMode"][value="floating"]').checked = true;
        document.getElementById('windowWidth').value = defaultSettings.windowWidth;
        document.getElementById('windowHeight').value = defaultSettings.windowHeight;
        document.getElementById('showPreview').checked = defaultSettings.showPreview;
        
        document.querySelectorAll('.position-button').forEach(button => {
            button.classList.toggle('selected', button.dataset.position === 'bottom-right');
        });
        
        toggleFloatingOptions(true);

        showSuccessMessage(
            document.getElementById('resetButton'),
            'איפוס להגדרות ברירת מחדל',
            'אופס בהצלחה!'
        );
    });
}

// פונקציה להצגת/הסתרת אפשרויות החלון הצף
function toggleFloatingOptions(show) {
    const floatingOptions = document.querySelector('.floating-options');
    if (floatingOptions) {
        if (show) {
            floatingOptions.style.display = 'block';
            floatingOptions.style.opacity = '0';
            setTimeout(() => {
                floatingOptions.style.opacity = '1';
            }, 0);
        } else {
            floatingOptions.style.opacity = '0';
            setTimeout(() => {
                floatingOptions.style.display = 'none';
            }, 300);
        }
    }
}

// הוספת מאזינים לאירועים
document.getElementById('saveSettings').addEventListener('click', saveSettings);
document.getElementById('resetButton').addEventListener('click', resetSettings);

// שמירת ההגדרות בשינוי מצב הנגן
document.querySelectorAll('input[name="playerMode"]').forEach(radio => {
    radio.addEventListener('change', (event) => {
        toggleFloatingOptions(event.target.value === 'floating');
    });
});

// שמירת הגדרות מיקום החלון
document.querySelectorAll('.position-button').forEach(button => {
    button.addEventListener('click', () => {
        document.querySelectorAll('.position-button').forEach(btn => {
            btn.classList.remove('selected');
        });
        button.classList.add('selected');
    });
});

document.getElementById('windowWidth').addEventListener('change', (event) => {
    const width = parseInt(event.target.value);
    if (width >= 200 && width <= 1200) {
        event.target.classList.remove('error');
    } else {
        event.target.classList.add('error');
    }
});

document.getElementById('windowHeight').addEventListener('change', (event) => {
    const height = parseInt(event.target.value);
    if (height >= 150 && height <= 800) {
        event.target.classList.remove('error');
    } else {
        event.target.classList.add('error');
    }
});
